@@ -3,19 +3,23 @@ import datetime
 import os 
 import pandas as pd
 class utility:
+
     def __init__(self):
         print("constructor created")
 
+
     def boto_session(self,aws_secret_access_key,aws_access_key_id,aws_session_token,region_name):
-        session = boto3.session.Session(
+        global session = boto3.session.Session(
         aws_access_key_id=aws_secret_access_key,
         aws_secret_access_key=aws_access_key_id,
         aws_session_token=aws_session_token,
         region_name=region_name
         )
         print("Boto3 Session Started")
+        return session
 
     def list_users(self,day):
+        session = boto_session
         iam = session.client(
         service_name='iam'
         )
